@@ -39,9 +39,7 @@
 #include <errno.h>
 #include <unistd.h>
 
-#include <glib/gmessages.h>
-#include <glib/gstrfuncs.h>
-#include <glib/gutils.h>
+#include <glib.h>
 
 #define size16 short
 #define size32 int
@@ -68,7 +66,7 @@ static void 	CDDBProcessLine(char *inbuffer,DiscData *data, int numtracks);
 static void CDDBWriteLine(char *header,int num,char *data,FILE *outfile);
 #endif
 
-static char *cddb_genres[] = {"unknown","blues","classical","country",
+static const char *cddb_genres[] = {"unknown","blues","classical","country",
 			      "data","folk","jazz","misc","newage",
 			      "reggae","rock","soundtrack"};
 
